pub struct EmittedText {
pub primary: String,
pub citations: Vec<ContractId>,
}Expand description
Plain text emitted by a single TargetEmitter before the
multi-emitter routing decides what to put in the final Artifact.
Doesn’t carry QuorumStatus (that’s chosen by the wrapper).
Fields
primary: Stringcitations: Vec<ContractId>Trait Implementations
Sourceimpl Clone for EmittedText
impl Clone for EmittedText
Sourcefn clone(&self) -> EmittedText
fn clone(&self) -> EmittedText
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmittedText
impl Debug for EmittedText
Sourceimpl<'de> Deserialize<'de> for EmittedText
impl<'de> Deserialize<'de> for EmittedText
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EmittedText
impl PartialEq for EmittedText
Sourcefn eq(&self, other: &EmittedText) -> bool
fn eq(&self, other: &EmittedText) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EmittedText
impl Serialize for EmittedText
impl StructuralPartialEq for EmittedText